=== modified file 'bzrlib/tests/script.py'
--- bzrlib/tests/script.py	2009-12-11 05:29:35 +0000
+++ bzrlib/tests/script.py	2010-01-13 02:45:07 +0000
@@ -24,6 +24,7 @@
 import glob
 import os
 import shlex
+import shutil
 from cStringIO import StringIO
 
 from bzrlib import (
@@ -402,6 +403,28 @@
             retcode = 0
         return retcode, None, err
 
+    def do_mv(self, test_case, input, args):
+        err = None
+        def error(msg, path1, path2):
+            return "mv: cannot move %s to %s: %s\n" % (path1, path2, msg)
+
+        if not args or len(args) != 2:
+            raise SyntaxError("Usage: mv path1 path2")
+        path1, path2 = args
+        try:
+            shutil.move(path1, path2)
+        except OSError, e:
+            if e.errno == errno.ENOENT:
+                err = error('No such file or directory', path1)
+            else:
+                raise
+        if err:
+            retcode = 1
+        else:
+            retcode = 0
+        return retcode, None, err
+
+
 
 class TestCaseWithMemoryTransportAndScript(tests.TestCaseWithMemoryTransport):
     """Helper class to experiment shell-like test and memory fs.

=== modified file 'bzrlib/tests/test_script.py'
--- bzrlib/tests/test_script.py	2009-11-08 20:28:36 +0000
+++ bzrlib/tests/test_script.py	2010-01-13 02:45:07 +0000
@@ -407,3 +407,28 @@
 $ rm -r dir
 """)
         self.failIfExists('dir')
+
+
+class TestMv(script.TestCaseWithTransportAndScript):
+
+    def test_usage(self):
+        self.assertRaises(SyntaxError, self.run_script, '$ mv')
+        self.assertRaises(SyntaxError, self.run_script, '$ mv f')
+        self.assertRaises(SyntaxError, self.run_script, '$ mv f1 f2 f3')
+
+    def test_move_file(self):
+        self.run_script('$ echo content >file')
+        self.failUnlessExists('file')
+        self.run_script('$ mv file new_name')
+        self.failIfExists('file')
+        self.failUnlessExists('new_name')
+
+    def test_move_dir(self):
+        self.run_script("""
+$ mkdir dir
+$ echo content >dir/file
+""")
+        self.run_script('$ mv dir new_name')
+        self.failIfExists('dir')
+        self.failUnlessExists('new_name')
+        self.failUnlessExists('new_name/file')

